# Web Exploit and Patch Project

In this project you will be looking for vulnerabilities in a realistic website. You will also be learning how to address those vulnerabilities. These vulnerabilities will be from the following categories:

* Cross-site scripting (XSS)
   * Reflected and stored
* Vulnerable web APIs
* SQL injection

You will be attacking these vulnerabilities on the [Juice Shop website](https://pwning.owasp-juice.shop/) provided by OWASP.

## Setup
If you are a Windows user, you **CAN** run this using Powershell. However, if you run into issues doing it this way, you will be on your own. 

I (James), personally recommend installing Kali Linux on a VM. From here on out, you will be doing penetration testing, and Kali should have all the tools you will need to find and execute your attacks. 

You could also install Ubuntu WSL2, though you may need to separately install some of the tools you may need. 

If you did not install WSL2 before installing Docker Desktop, you will need to go through these steps before proceeding.  

1. Navigate to Settings.

2. From the General tab, select Use WSL 2 based engine.. If you have installed Docker Desktop on a system that supports WSL 2, this option is turned on by default.

3. Select Apply & Restart.

Once you have finished the above steps, run the following commands in Powershell, to connect WSL2 to Docker Desktop.

```bash
# Checks the distro
wsl.exe -l -v
# upgrades distro to version2
wsl.exe --set-version (distro name) 2
# Sets version2 as the default
wsl.exe --set-default-version 2
# Enables the DOCKER-WSL integration
wsl --set-default <distro name>
```

## Running

To start, visit the [Juice Shop information website](https://pwning.owasp-juice.shop/). You will need to follow the instruction on [running OWASP Juice Shop](https://pwning.owasp-juice.shop/part1/running.html) to get this project setup and running. Personally, I recommend that you run Juice Shop using docker. 

To download and start the container, run this command: 

```bash
docker run --rm -p 3000:3000 -e NODE_ENV=unsafe bkimminich/juice-shop
```

## Hints

* Start by getting familiarized with the application. Create a user account and maybe make an order or two.
* If you need to enter information, such as a credit card number or an address, remember that Juice Shop only has very basic data validation. As long as the data looks right, that is good enough. No need to use real values.
* A good place to start looking is in `main.js`.
* Another great resource is the developer tools for your browser.
   * In particular, use the network tab to look at the requests being made by the website during normal operation.
   * In the network tab, you can copy previous web requests into many different formats. This makes it easy to replicate or modify those requests.
   * If you need to encode a URL, you can use `encodeURIComponent` in the developer tools console.
* API-Only XSS
   * What is a [bearer token](https://cheatsheetseries.owasp.org/cheatsheets/JSON_Web_Token_for_Java_Cheat_Sheet.html)?
   * How are HTTP methods used by default for a [REST API](https://www.restapitutorial.com/lessons/httpmethods.html)?


## Writeup
As you solve each problem, you will write up details about your solutions in `submission.md`. This is the file that you will submit on Canvas. When describing your steps, use complete sentences and describe clearly what you did.